@@ -5,13 +5,9 @@ def test_base():
     get_osm_data(
         region_list=["benin"],
         primary_name="power",
-        feature_list=["substation", "line", "generator", "tower"],
+        feature_list=["tower"],
         update=True,
         mp=True,
         out_format=["csv", "geojson"],
         out_aggregate=False,
     )
-
-
-if __name__ == 'main':
-    test_base()
\ No newline at end of file
